registerWith static method
Implementation
static void registerWith(Registrar registrar) {
// No-op: Infusion's web backend is driven through js_interop, not a
// MethodChannel, so there is no handler to register here.
}
static void registerWith(Registrar registrar) {
// No-op: Infusion's web backend is driven through js_interop, not a
// MethodChannel, so there is no handler to register here.
}